require "devflow/command"

module DevFlow
  module Commands
    class PR < DevFlow::Command
      STORY_URL_BASE = "#{DevFlow::TargetProcess::BASE_URI}/entity"
      STORY_URL_PATTERN = /#{STORY_URL_BASE}\/(\d+)/
      STORY_REGEX = /^(\d+)-(.*)/
      FV_REGEX = /^fv-(.*)/
      PR_TEMPLATES_PATHS = %w[
        .github/PULL_REQUEST_TEMPLATE.md
      ]

      def call
        branch = `git rev-parse --abbrev-ref HEAD`

        case branch
        when STORY_REGEX
          story_id = $1
          story_url = STORY_URL_BASE + "/" + story_id
          title = "[#{story_id}] #{titleize($2)}"
        when FV_REGEX
          story_url = ""
          title = "[FV] #{titleize($1)}"
        else
          story_url = ""
          title = titleize(branch)
        end

        message =
          if (file = PR_TEMPLATES_PATHS.find { |p| File.exist?(p) })
            "#{title}\n" \
              "\n" \
              "#{File.read(file).gsub(STORY_URL_PATTERN, story_url)}"
          else
            "#{title}\n" \
              "\n" \
              "#{story_url}"
          end

        puts message
      end

      def titleize(str)
        str.tr("-", " ").capitalize
      end
    end
  end
end
