require "httparty"
require "devflow/target_process/error"

module DevFlow
  class TargetProcess
    include HTTParty

    BASE_URI = ENV["TP_BASE_URL"]
    USER_ID = ENV["TP_USER_ID"]
    ACCESS_TOKEN = ENV["TP_ACCESS_TOKEN"]
    ENTITY_PATTERN = /#{BASE_URI}\/entity\/(\d+)/.freeze

    base_uri BASE_URI
    headers "Content-Type" => "application/json"
    format :json
    default_params(
      access_token: ACCESS_TOKEN,
      format: "json"
    )

    def self.check_config!
      raise ConfigError, "TP_ACCESS_TOKEN" unless ACCESS_TOKEN
      raise ConfigError, "TP_BASE_URL" unless BASE_URI
      raise ConfigError, "TP_ACCESS_TOKEN" unless ACCESS_TOKEN
    end

    def self.assignments
      where = "(GeneralUser.Id eq #{USER_ID})and" \
        "(Assignable.EntityState.Name eq 'In Progress')"
      response = request(
        :get,
        "/api/v1/assignments",
        query: { where: where, include: "[Assignable[Id,Name]]" }
      )

      response["Items"].map do |i|
        { id: i["Assignable"]["Id"], name: i["Assignable"]["Name"] }
      end
    end

    def self.request(method, *args)
      response = send(method, *args)

      raise TargetProcess::RequestError, response unless response.code == 200

      response
    end
  end
end
